@@ -1,6 +1,6 @@
 /*
- *  MailSvr by Davide Libenzi ( Intranet and Internet mail server )
- *  Copyright (C) 1999  Davide Libenzi
+ *  XMail by Davide Libenzi ( Intranet and Internet mail server )
+ *  Copyright (C) 1999,2000,2001  Davide Libenzi
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  Davide Libenzi <davide_libenzi@mycio.com>
+ *  Davide Libenzi <davidel@xmailserver.org>
  *
  */
 
@@ -40,6 +40,7 @@
 #include "POP3GwLink.h"
 #include "MailDomains.h"
 #include "SMAILUtils.h"
+#include "SMTPUtils.h"
 #include "MailConfig.h"
 #include "AppDefines.h"
 #include "MailSvr.h"
@@ -262,7 +263,7 @@ static int      CTRLLogSession(char const * pszUsername, char const * pszPasswor
     MscGetTimeNbrString(szTime, sizeof(szTime) - 1);
 
 
-    RLCK_HANDLE     hResLock = RLckLockEX(SVR_LOGS_DIR "/" CTRL_LOG_FILE);
+    RLCK_HANDLE     hResLock = RLckLockEX(SVR_LOGS_DIR SYS_SLASH_STR CTRL_LOG_FILE);
 
     if (hResLock == INVALID_RLCK_HANDLE)
         return (ErrGetErrorCode());
@@ -323,19 +324,10 @@ static int      CTRLThreadCountAdd(long lCount, SHB_HANDLE hShbCTRL,
 unsigned int    CTRLThreadProc(void *pThreadData)
 {
 
-    SHB_HANDLE      hShbCTRL = ShbConnectBlock(SHB_CTRLSvr);
-
-    if (hShbCTRL == SHB_INVALID_HANDLE)
-        return (ErrGetErrorCode());
-
     CTRLConfig     *pCTRLCfg = (CTRLConfig *) ShbLock(hShbCTRL);
 
     if (pCTRLCfg == NULL)
-    {
-        ErrorPush();
-        ShbCloseBlock(hShbCTRL);
-        return (ErrorPop());
-    }
+        return (ErrGetErrorCode());
 
 
     int             iNumSockFDs = 0;
@@ -347,14 +339,11 @@ unsigned int    CTRLThreadProc(void *pThreadData)
         ErrorPush();
         SysLogMessage(LOG_LEV_ERROR, "%s\n", ErrGetErrorString());
         ShbUnlock(hShbCTRL);
-        ShbCloseBlock(hShbCTRL);
         return (ErrorPop());
     }
 
     ShbUnlock(hShbCTRL);
 
-    SysIgnoreThreadsExit();
-
 
     SysLogMessage(LOG_LEV_MESSAGE, "%s started\n", CTRL_SERVER_NAME);
 
@@ -389,7 +378,7 @@ unsigned int    CTRLThreadProc(void *pThreadData)
             if (hClientThread != SYS_INVALID_THREAD)
                 SysCloseThread(hClientThread, 0);
             else
-                SysCloseSocket(ConnSockFD[ss], 1);
+                SysCloseSocket(ConnSockFD[ss]);
 
         }
     }
@@ -417,8 +406,6 @@ unsigned int    CTRLThreadProc(void *pThreadData)
         SysSleep(CTRL_WAIT_SLEEP);
     }
 
-    ShbCloseBlock(hShbCTRL);
-
     SysLogMessage(LOG_LEV_MESSAGE, "%s stopped\n", CTRL_SERVER_NAME);
 
     return (0);
@@ -432,19 +419,6 @@ static unsigned int CTRLClientThread(void *pThreadData)
 
     SYS_SOCKET      SockFD = (SYS_SOCKET) (unsigned int) pThreadData;
 
-///////////////////////////////////////////////////////////////////////////////
-//  Create handle to hook shared memory
-///////////////////////////////////////////////////////////////////////////////
-    SHB_HANDLE      hShbCTRL = ShbConnectBlock(SHB_CTRLSvr);
-
-    if (hShbCTRL == SHB_INVALID_HANDLE)
-    {
-        ErrorPush();
-        SysLogMessage(LOG_LEV_ERROR, "%s\n", ErrGetErrorString());
-        SysCloseSocket(SockFD);
-        return (ErrorPop());
-    }
-
 ///////////////////////////////////////////////////////////////////////////////
 //  Link socket to the bufferer
 ///////////////////////////////////////////////////////////////////////////////
@@ -455,7 +429,6 @@ static unsigned int CTRLClientThread(void *pThreadData)
         ErrorPush();
         SysLogMessage(LOG_LEV_ERROR, "%s\n", ErrGetErrorString());
         SysCloseSocket(SockFD);
-        ShbCloseBlock(hShbCTRL);
         return (ErrorPop());
     }
 
@@ -469,7 +442,6 @@ static unsigned int CTRLClientThread(void *pThreadData)
         CTRLSendCmdResult(hBSock, ErrorFetch(), ErrGetErrorString(), STD_CTRL_TIMEOUT);
 
         BSckDetach(hBSock, 1);
-        ShbCloseBlock(hShbCTRL);
         return (ErrorPop());
     }
 
@@ -484,7 +456,6 @@ static unsigned int CTRLClientThread(void *pThreadData)
 
         SysLogMessage(LOG_LEV_ERROR, "%s\n", ErrGetErrorString(ErrorFetch()));
         BSckDetach(hBSock, 1);
-        ShbCloseBlock(hShbCTRL);
         return (ErrorPop());
     }
 
@@ -499,7 +470,6 @@ static unsigned int CTRLClientThread(void *pThreadData)
         SysLogMessage(LOG_LEV_ERROR, "%s\n", ErrGetErrorString());
         BSckDetach(hBSock, 1);
         CTRLThreadCountAdd(-1, hShbCTRL);
-        ShbCloseBlock(hShbCTRL);
         return (ErrorPop());
     }
 
@@ -527,8 +497,6 @@ static unsigned int CTRLClientThread(void *pThreadData)
     CTRLThreadCountAdd(-1, hShbCTRL);
 
 
-    ShbCloseBlock(hShbCTRL);
-
     return (0);
 
 }
@@ -706,7 +674,8 @@ static int      CTRLLogin(CTRLConfig * pCTRLCfg, BSOCK_HANDLE hBSock,
 
     char            szLogin[256] = "";
 
-    if (BSckGetString(hBSock, szLogin, sizeof(szLogin) - 1, pCTRLCfg->iTimeout) == NULL)
+    if ((BSckGetString(hBSock, szLogin, sizeof(szLogin) - 1, pCTRLCfg->iTimeout) == NULL) ||
+            (MscCmdStringCheck(szLogin) < 0))
         return (ErrGetErrorCode());
 
 
@@ -799,7 +768,7 @@ static int      CTRLHandleSession(SHB_HANDLE hShbCTRL, BSOCK_HANDLE hBSock,
 ///////////////////////////////////////////////////////////////////////////////
 //  Welcome
 ///////////////////////////////////////////////////////////////////////////////
-	char            szTime[256] = "";
+    char            szTime[256] = "";
 
     MscGetTimeStr(szTime, sizeof(szTime) - 1);
 
@@ -821,10 +790,11 @@ static int      CTRLHandleSession(SHB_HANDLE hShbCTRL, BSOCK_HANDLE hBSock,
 ///////////////////////////////////////////////////////////////////////////////
 //  Command loop
 ///////////////////////////////////////////////////////////////////////////////
-    char            szBuffer[CTRL_MAX_LINE_SIZE] = "";
+    char            szCommand[CTRL_MAX_LINE_SIZE] = "";
 
     while (!SvrInShutdown() &&
-            (BSckGetString(hBSock, szBuffer, sizeof(szBuffer) - 1, iSessionTimeout) != NULL))
+            (BSckGetString(hBSock, szCommand, sizeof(szCommand) - 1, iSessionTimeout) != NULL) &&
+            (MscCmdStringCheck(szCommand) == 0))
     {
 ///////////////////////////////////////////////////////////////////////////////
 //  Check for exit flag
@@ -841,7 +811,7 @@ static int      CTRLHandleSession(SHB_HANDLE hShbCTRL, BSOCK_HANDLE hBSock,
 ///////////////////////////////////////////////////////////////////////////////
 //  Process client command
 ///////////////////////////////////////////////////////////////////////////////
-        int             iCmdResult = CTRLProcessCommand(pCTRLCfg, hBSock, szBuffer);
+        int             iCmdResult = CTRLProcessCommand(pCTRLCfg, hBSock, szCommand);
 
         SysFree(pCTRLCfg);
 
@@ -1128,7 +1098,16 @@ static int      CTRLDo_aliasadd(CTRLConfig * pCTRLCfg, BSOCK_HANDLE hBSock,
 ///////////////////////////////////////////////////////////////////////////////
 //  Check real user account existence
 ///////////////////////////////////////////////////////////////////////////////
-    UserInfo       *pUI = UsrGetUserByName(ppszTokens[1], ppszTokens[3]);
+    char            szAccountName[MAX_ADDR_NAME] = "",
+                    szAccountDomain[MAX_ADDR_NAME] = "";
+
+    if (USmtpSplitEmailAddr(ppszTokens[3], szAccountName, szAccountDomain) < 0)
+    {
+        StrSNCpy(szAccountName, ppszTokens[3]);
+        StrSNCpy(szAccountDomain, ppszTokens[1]);
+    }
+
+    UserInfo       *pUI = UsrGetUserByName(szAccountDomain, szAccountName);
 
     if (pUI == NULL)
     {
@@ -1718,7 +1697,7 @@ static int      CTRLDo_mluseradd(CTRLConfig * pCTRLCfg, BSOCK_HANDLE hBSock,
     }
 
 
-    char const     *pszPerms = (iTokensCount > 4) ? ppszTokens[4]: DEFAULT_MLUSER_PERMS;
+    char const     *pszPerms = (iTokensCount > 4) ? ppszTokens[4] : DEFAULT_MLUSER_PERMS;
     MLUserInfo     *pMLUI = UsrMLAllocDefault(ppszTokens[3], pszPerms);
 
     if (pMLUI == NULL)
@@ -1908,7 +1887,8 @@ static int      CTRLDo_domainadd(CTRLConfig * pCTRLCfg, BSOCK_HANDLE hBSock,
 
     char            szDomain[256] = "";
 
-    StrLower(strcpy(szDomain, ppszTokens[1]));
+    StrSNCpy(szDomain, ppszTokens[1]);
+    StrLower(szDomain);
 
     if (MDomAddDomain(szDomain) < 0)
     {
@@ -1941,7 +1921,8 @@ static int      CTRLDo_domaindel(CTRLConfig * pCTRLCfg, BSOCK_HANDLE hBSock,
 
     char            szDomain[256] = "";
 
-    StrLower(strcpy(szDomain, ppszTokens[1]));
+    StrSNCpy(szDomain, ppszTokens[1]);
+    StrLower(szDomain);
 
     if (MDomRemoveDomain(szDomain) < 0)
     {
@@ -2383,6 +2364,7 @@ static int      CTRLDo_poplnklist(CTRLConfig * pCTRLCfg, BSOCK_HANDLE hBSock,
             if (((pszDomain == NULL) || (stricmp(pPopLnk->pszDomain, pszDomain) == 0)) &&
                     ((pszName == NULL) || (stricmp(pPopLnk->pszName, pszName) == 0)))
             {
+                char const     *pszEnable = (GwLkCheckEnabled(pPopLnk) == 0) ? "ON": "OFF";
                 char            szLinkLine[2048] = "";
 
                 sprintf(szLinkLine,
@@ -2390,9 +2372,12 @@ static int      CTRLDo_poplnklist(CTRLConfig * pCTRLCfg, BSOCK_HANDLE hBSock,
                         "\"%s\"\t"
                         "\"%s\"\t"
                         "\"%s\"\t"
+                        "\"%s\"\t"
+                        "\"%s\"\t"
                         "\"%s\"",
                         pPopLnk->pszDomain, pPopLnk->pszName, pPopLnk->pszRmtDomain,
-                        pPopLnk->pszRmtName, pPopLnk->pszRmtPassword);
+                        pPopLnk->pszRmtName, pPopLnk->pszRmtPassword, pPopLnk->pszAuthType,
+                        pszEnable);
 
                 if (BSckSendString(hBSock, szLinkLine, pCTRLCfg->iTimeout) < 0)
                 {
@@ -2468,7 +2453,7 @@ static int      CTRLDo_cfgfileget(CTRLConfig * pCTRLCfg, BSOCK_HANDLE hBSock,
     char            szRelativePath[SYS_MAX_PATH] = "",
                     szFullPath[SYS_MAX_PATH] = "";
 
-    strcpy(szRelativePath, ppszTokens[1]);
+    StrSNCpy(szRelativePath, ppszTokens[1]);
     MscTranslatePath(szRelativePath);
 
     CfgGetFullPath(szRelativePath, szFullPath);
@@ -2543,7 +2528,7 @@ static int      CTRLDo_cfgfileset(CTRLConfig * pCTRLCfg, BSOCK_HANDLE hBSock,
     char            szRelativePath[SYS_MAX_PATH] = "",
                     szFullPath[SYS_MAX_PATH] = "";
 
-    strcpy(szRelativePath, ppszTokens[1]);
+    StrSNCpy(szRelativePath, ppszTokens[1]);
     MscTranslatePath(szRelativePath);
 
     CfgGetFullPath(szRelativePath, szFullPath);
