@@ -1,6 +1,6 @@
 /*
- *  MailSvr by Davide Libenzi ( Intranet and Internet mail server )
- *  Copyright (C) 1999  Davide Libenzi
+ *  XMail by Davide Libenzi ( Intranet and Internet mail server )
+ *  Copyright (C) 1999,2000,2001  Davide Libenzi
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  Davide Libenzi <davide_libenzi@mycio.com>
+ *  Davide Libenzi <davidel@xmailserver.org>
  *
  */
 
@@ -39,12 +39,18 @@
 
 
 #define DNS_PORTNO              53
-#define DNS_SOCKET_TIMEOUT      20
+#define DNS_SOCKET_TIMEOUT      16
 #define DNS_QUERY_EXTRA         512
 #define DNS_MAX_RESP_PACKET     1024
-#define DNS_SEND_RETRIES        4
+#define DNS_SEND_RETRIES        3
 #define DNS_MAX_RR_DATA         256
+
+#if defined(LITTLE_ENDIAN_CPU)
 #define DNS_LABEL_LEN_MASK      0xff3f
+#else           // #if defined(LITTLE_ENDIAN_CPU)
+#define DNS_LABEL_LEN_MASK      0x3fff
+#endif          // #if defined(LITTLE_ENDIAN_CPU)
+
 #define DNS_LABEL_LEN_INVMASK   0xc0
 
 #define ROOTS_FILE              "dnsroots"
@@ -75,7 +81,8 @@ struct DNSResourceRecord
 struct DNSNameNode
 {
     LISTLINK        LL;
-    char           *pszName;
+    char           *pszServer;
+    char           *pszQuery;
 };
 
 
@@ -83,11 +90,11 @@ struct DNSNameNode
 
 
 
-static DNSNameNode *DNS_AllocNameNode(char const * pszName);
+static DNSNameNode *DNS_AllocNameNode(char const * pszServer, char const * pszQuery);
 static void     DNS_FreeNameNode(DNSNameNode * pDNSNN);
 static void     DNS_FreeNameList(HSLIST & hNameList);
-static DNSNameNode *DNS_GetNameNode(HSLIST & hNameList, char const * pszName);
-static int      DNS_AddNameNode(HSLIST & hNameList, char const * pszName);
+static DNSNameNode *DNS_GetNameNode(HSLIST & hNameList, char const * pszServer, char const * pszQuery);
+static int      DNS_AddNameNode(HSLIST & hNameList, char const * pszServer, char const * pszQuery);
 static int      DNS_GetResourceRecord(SYS_UINT8 const * pBaseData, SYS_UINT8 const * pRespData,
                         DNSResourceRecord * pRR = NULL);
 static int      DNS_GetName(SYS_UINT8 const * pBaseData, SYS_UINT8 const * pRespData,
@@ -129,7 +136,7 @@ static char    *DNS_GetRootsFile(char *pszRootsFilePath);
 
 
 
-static DNSNameNode *DNS_AllocNameNode(char const * pszName)
+static DNSNameNode *DNS_AllocNameNode(char const * pszServer, char const * pszQuery)
 {
 
     DNSNameNode    *pDNSNN = (DNSNameNode *) SysAlloc(sizeof(DNSNameNode));
@@ -139,12 +146,19 @@ static DNSNameNode *DNS_AllocNameNode(char const * pszName)
 
     ListLinkInit(pDNSNN);
 
-    if ((pDNSNN->pszName = SysStrDup(pszName)) == NULL)
+    if ((pDNSNN->pszServer = SysStrDup(pszServer)) == NULL)
     {
         SysFree(pDNSNN);
         return (NULL);
     }
 
+    if ((pDNSNN->pszQuery = SysStrDup(pszQuery)) == NULL)
+    {
+        SysFree(pDNSNN->pszServer);
+        SysFree(pDNSNN);
+        return (NULL);
+    }
+
     return (pDNSNN);
 
 }
@@ -155,7 +169,9 @@ static DNSNameNode *DNS_AllocNameNode(char const * pszName)
 static void     DNS_FreeNameNode(DNSNameNode * pDNSNN)
 {
 
-    SysFree(pDNSNN->pszName);
+    SysFree(pDNSNN->pszQuery);
+
+    SysFree(pDNSNN->pszServer);
 
     SysFree(pDNSNN);
 
@@ -177,14 +193,15 @@ static void     DNS_FreeNameList(HSLIST & hNameList)
 
 
 
-static DNSNameNode *DNS_GetNameNode(HSLIST & hNameList, char const * pszName)
+static DNSNameNode *DNS_GetNameNode(HSLIST & hNameList, char const * pszServer, char const * pszQuery)
 {
 
     DNSNameNode    *pDNSNN = (DNSNameNode *) ListFirst(hNameList);
 
     for (; pDNSNN != INVALID_SLIST_PTR; pDNSNN = (DNSNameNode *)
             ListNext(hNameList, (PLISTLINK) pDNSNN))
-        if (stricmp(pDNSNN->pszName, pszName) == 0)
+        if ((stricmp(pDNSNN->pszServer, pszServer) == 0) &&
+                (stricmp(pDNSNN->pszQuery, pszQuery) == 0))
             return (pDNSNN);
 
     return (NULL);
@@ -193,10 +210,10 @@ static DNSNameNode *DNS_GetNameNode(HSLIST & hNameList, char const * pszName)
 
 
 
-static int      DNS_AddNameNode(HSLIST & hNameList, char const * pszName)
+static int      DNS_AddNameNode(HSLIST & hNameList, char const * pszServer, char const * pszQuery)
 {
 
-    DNSNameNode    *pDNSNN = DNS_AllocNameNode(pszName);
+    DNSNameNode    *pDNSNN = DNS_AllocNameNode(pszServer, pszQuery);
 
     if (pDNSNN == NULL)
         return (ErrGetErrorCode());
@@ -228,7 +245,7 @@ static int      DNS_GetResourceRecord(SYS_UINT8 const * pBaseData, SYS_UINT8 con
 //  Read type field
 ///////////////////////////////////////////////////////////////////////////////
     if (pRR != NULL)
-        pRR->Type = ntohs(*((SYS_UINT16 *) pRespData));
+        pRR->Type = ntohs(MscReadUint16(pRespData));
 
     pRespData += sizeof(SYS_UINT16);
     iRRLen += sizeof(SYS_UINT16);
@@ -237,7 +254,7 @@ static int      DNS_GetResourceRecord(SYS_UINT8 const * pBaseData, SYS_UINT8 con
 //  Read class field
 ///////////////////////////////////////////////////////////////////////////////
     if (pRR != NULL)
-        pRR->Class = ntohs(*((SYS_UINT16 *) pRespData));
+        pRR->Class = ntohs(MscReadUint16(pRespData));
 
     pRespData += sizeof(SYS_UINT16);
     iRRLen += sizeof(SYS_UINT16);
@@ -246,7 +263,7 @@ static int      DNS_GetResourceRecord(SYS_UINT8 const * pBaseData, SYS_UINT8 con
 //  Read TTL field
 ///////////////////////////////////////////////////////////////////////////////
     if (pRR != NULL)
-        pRR->TTL = ntohl(*((SYS_UINT32 *) pRespData));
+        pRR->TTL = ntohl(MscReadUint32(pRespData));
 
     pRespData += sizeof(SYS_UINT32);
     iRRLen += sizeof(SYS_UINT32);
@@ -254,7 +271,7 @@ static int      DNS_GetResourceRecord(SYS_UINT8 const * pBaseData, SYS_UINT8 con
 ///////////////////////////////////////////////////////////////////////////////
 //  Read lenght field
 ///////////////////////////////////////////////////////////////////////////////
-    SYS_UINT16      Lenght = ntohs(*((SYS_UINT16 *) pRespData));
+    SYS_UINT16      Lenght = ntohs(MscReadUint16(pRespData));
 
     if (pRR != NULL)
         pRR->Lenght = Lenght;
@@ -293,7 +310,7 @@ static int      DNS_GetName(SYS_UINT8 const * pBaseData, SYS_UINT8 const * pResp
     {
         if (*pRespData & DNS_LABEL_LEN_INVMASK)
         {
-            int             iLabelOffset = (int) ntohs(*((SYS_UINT16 *) pRespData) & DNS_LABEL_LEN_MASK);
+            int             iLabelOffset = (int) ntohs(MscReadUint16(pRespData) & DNS_LABEL_LEN_MASK);
 
             pRespData = pBaseData + iLabelOffset;
 
@@ -337,7 +354,7 @@ static int      DNS_GetQuery(SYS_UINT8 const * pBaseData, SYS_UINT8 const * pRes
 //  Read type field
 ///////////////////////////////////////////////////////////////////////////////
     if (pType != NULL)
-        *pType = ntohs(*((SYS_UINT16 *) pRespData));
+        *pType = ntohs(MscReadUint16(pRespData));
 
     pRespData += sizeof(SYS_UINT16);
     iQueryLen += sizeof(SYS_UINT16);
@@ -346,7 +363,7 @@ static int      DNS_GetQuery(SYS_UINT8 const * pBaseData, SYS_UINT8 const * pRes
 //  Read class field
 ///////////////////////////////////////////////////////////////////////////////
     if (pClass != NULL)
-        *pClass = ntohs(*((SYS_UINT16 *) pRespData));
+        *pClass = ntohs(MscReadUint16(pRespData));
 
     pRespData += sizeof(SYS_UINT16);
     iQueryLen += sizeof(SYS_UINT16);
@@ -366,7 +383,10 @@ static int      DNS_NameCopy(SYS_UINT8 * pDNSQName, char const * pszInetName)
         return (ErrGetErrorCode());
 
     int             iNameLen = 0;
-    char           *pszToken = strtok(pszNameCopy, ".");
+    char           *pszToken = NULL,
+                   *pszSavePtr = NULL;
+
+    pszToken = SysStrTok(pszNameCopy, ".", &pszSavePtr);
 
     while (pszToken != NULL)
     {
@@ -379,7 +399,7 @@ static int      DNS_NameCopy(SYS_UINT8 * pDNSQName, char const * pszInetName)
         pDNSQName += iTokLen + 1;
         iNameLen += iTokLen + 1;
 
-        pszToken = strtok(NULL, ".");
+        pszToken = SysStrTok(NULL, ".", &pszSavePtr);
     }
 
     *pDNSQName = 0;
@@ -435,13 +455,13 @@ static int      DNS_RequestSetup(DNSQuery & DNSQ, unsigned int uOpCode,
 ///////////////////////////////////////////////////////////////////////////////
 //  Set query type
 ///////////////////////////////////////////////////////////////////////////////
-    *((SYS_UINT16 *) pQueryData) = (SYS_UINT16) htons(uQType);
+    MscWriteUint16(pQueryData, (SYS_UINT16) htons(uQType));
     pQueryData += sizeof(SYS_UINT16);
 
 ///////////////////////////////////////////////////////////////////////////////
 //  Set query class
 ///////////////////////////////////////////////////////////////////////////////
-    *((SYS_UINT16 *) pQueryData) = (SYS_UINT16) htons(QCLASS_IN);
+    MscWriteUint16(pQueryData, (SYS_UINT16) htons(QCLASS_IN));
     pQueryData += sizeof(SYS_UINT16);
 
 
@@ -601,8 +621,7 @@ static SYS_UINT8 *DNS_QuerySendDGram(char const * pszDNSServer, int iPortNo, int
 ///////////////////////////////////////////////////////////////////////////////
 //  Send packet
 ///////////////////////////////////////////////////////////////////////////////
-        if (SysSendDataTo(SockFD, (const struct sockaddr *) & SvrAddr, sizeof(SvrAddr),
-                        (char const *) &DNSQ, iQueryLenght, iTimeout) != iQueryLenght)
+        if (SysSendData(SockFD, (char const *) &DNSQ, iQueryLenght, iTimeout) != iQueryLenght)
             continue;
 
 ///////////////////////////////////////////////////////////////////////////////
@@ -617,7 +636,7 @@ static SYS_UINT8 *DNS_QuerySendDGram(char const * pszDNSServer, int iPortNo, int
                 (char *) RespBuffer, sizeof(RespBuffer), iTimeout);
 
 
-        if (iPacketLenght < sizeof(DNS_HEADER))
+        if ((iPacketLenght < 0) || (iPacketLenght < sizeof(DNS_HEADER)))
             continue;
 
         DNS_HEADER     *pDNSH = (DNS_HEADER *) RespBuffer;
@@ -737,7 +756,7 @@ static int      DNS_DecodeResponseMX(SYS_UINT8 * pRespData, char const * pszDoma
 
 
         SYS_UINT8      *pMXData = RR.RespData;
-        SYS_UINT16      Preference = ntohs(*((SYS_UINT16 *) pMXData));
+        SYS_UINT16      Preference = ntohs(MscReadUint16(pMXData));
 
         pMXData += sizeof(SYS_UINT16);
 
@@ -788,7 +807,7 @@ static int      DNS_DecodeResponseMX(SYS_UINT8 * pRespData, char const * pszDoma
 ///////////////////////////////////////////////////////////////////////////////
 //  Recursively try authority name servers
 ///////////////////////////////////////////////////////////////////////////////
-        if ((DNS_GetNameNode(hNameList, szNSName) == NULL) &&
+        if ((DNS_GetNameNode(hNameList, szNSName, pszDomain) == NULL) &&
                 DNS_FindDomainMX(szNSName, pszDomain, hNameList, pszRespFile, pTTL) == 0)
             return (0);
 
@@ -889,7 +908,7 @@ static int      DNS_DecodeResponseMX(SYS_UINT8 * pRespData, char const * pszResp
 
 
         SYS_UINT8      *pMXData = RR.RespData;
-        SYS_UINT16      Preference = ntohs(*((SYS_UINT16 *) pMXData));
+        SYS_UINT16      Preference = ntohs(MscReadUint16(pMXData));
 
         pMXData += sizeof(SYS_UINT16);
 
@@ -1093,7 +1112,7 @@ static int      DNS_FindDomainMX(char const * pszDNSServer, char const * pszDoma
 ///////////////////////////////////////////////////////////////////////////////
 //  Add this server to the visited list
 ///////////////////////////////////////////////////////////////////////////////
-    DNS_AddNameNode(hNameList, pszDNSServer);
+    DNS_AddNameNode(hNameList, pszDNSServer, pszDomain);
 
 ///////////////////////////////////////////////////////////////////////////////
 //  Decode server response ( recursive )
@@ -1239,7 +1258,7 @@ static int      DNS_GetNameServersLL(char const * pszDNSServer, char const * psz
 ///////////////////////////////////////////////////////////////////////////////
 //  Add this server to the visited list
 ///////////////////////////////////////////////////////////////////////////////
-    DNS_AddNameNode(hNameList, pszDNSServer);
+    DNS_AddNameNode(hNameList, pszDNSServer, pszDomain);
 
 
     FILE           *pNSFile = fopen(szRespFile, "rt");
@@ -1256,7 +1275,7 @@ static int      DNS_GetNameServersLL(char const * pszDNSServer, char const * psz
 
     while (MscFGets(szNS, sizeof(szNS) - 1, pNSFile) != NULL)
     {
-        if ((DNS_GetNameNode(hNameList, szNS) == NULL) &&
+        if ((DNS_GetNameNode(hNameList, szNS, pszDomain) == NULL) &&
                 (DNS_GetNameServersLL(szNS, pszDomain, pszRespFile, hNameList, pTTL) == 0))
         {
             fclose(pNSFile);
