@@ -1,6 +1,6 @@
 /*
- *  MailSvr by Davide Libenzi ( Intranet and Internet mail server )
- *  Copyright (C) 1999  Davide Libenzi
+ *  XMail by Davide Libenzi ( Intranet and Internet mail server )
+ *  Copyright (C) 1999,2000,2001  Davide Libenzi
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  Davide Libenzi <davide_libenzi@mycio.com>
+ *  Davide Libenzi <davidel@xmailserver.org>
  *
  */
 
@@ -136,14 +136,6 @@ static int      PSYNCTimeToStop(SHB_HANDLE hShbPSYNC)
 unsigned int    PSYNCThreadProc(void *pThreadData)
 {
 
-    SysIgnoreThreadsExit();
-
-    SHB_HANDLE      hShbPSYNC = ShbConnectBlock(SHB_PSYNCSvr);
-
-    if (hShbPSYNC == SHB_INVALID_HANDLE)
-        return (ErrGetErrorCode());
-
-
     SysLogMessage(LOG_LEV_MESSAGE, "%s started\n", PSYNC_SERVER_NAME);
 
 
@@ -203,8 +195,6 @@ unsigned int    PSYNCThreadProc(void *pThreadData)
     }
 
 
-    ShbCloseBlock(hShbPSYNC);
-
     SysLogMessage(LOG_LEV_MESSAGE, "%s stopped\n", PSYNC_SERVER_NAME);
 
     return (0);
@@ -216,24 +206,12 @@ unsigned int    PSYNCThreadProc(void *pThreadData)
 static int      PSYNCStartTransfer(SHB_HANDLE hShbPSYNC, PSYNCConfig * pPSYNCCfg)
 {
 
-    SYS_SEMAPHORE   SemSyncID = SysConnectSemaphore(pPSYNCCfg->iNumSyncThreads,
-            SYS_DEFAULT_MAXCOUNT, SemPSYNCThreads);
-
-    if (SemSyncID == SYS_INVALID_SEMAPHORE)
-    {
-        ErrorPush();
-        SysLogMessage(LOG_LEV_ERROR, "%s\n", ErrGetErrorString(ErrorFetch()));
-        return (ErrorPop());
-    }
-
-
     GWLKF_HANDLE    hLinksDB = GwLkOpenDB();
 
     if (hLinksDB == INVALID_GWLKF_HANDLE)
     {
         ErrorPush();
         SysLogMessage(LOG_LEV_ERROR, "%s\n", ErrGetErrorString(ErrorFetch()));
-        SysCloseSemaphore(SemSyncID);
         return (ErrorPop());
     }
 
@@ -249,7 +227,7 @@ static int      PSYNCStartTransfer(SHB_HANDLE hShbPSYNC, PSYNCConfig * pPSYNCCfg
             continue;
 
 
-        if (SysWaitSemaphore(SemSyncID, SYS_INFINITE_TIMEOUT) < 0)
+        if (SysWaitSemaphore(hSyncSem, SYS_INFINITE_TIMEOUT) < 0)
             break;
 
         if (PSYNCTimeToStop(hShbPSYNC))
@@ -264,15 +242,12 @@ static int      PSYNCStartTransfer(SHB_HANDLE hShbPSYNC, PSYNCConfig * pPSYNCCfg
         {
             GwLkFreePOP3Link(pPopLnk);
 
-            SysReleaseSemaphore(SemSyncID, 1);
+            SysReleaseSemaphore(hSyncSem, 1);
         }
     }
 
     GwLkCloseDB(hLinksDB);
 
-
-    SysCloseSemaphore(SemSyncID);
-
     return (0);
 
 }
@@ -283,15 +258,7 @@ static int      PSYNCStartTransfer(SHB_HANDLE hShbPSYNC, PSYNCConfig * pPSYNCCfg
 static int      PSYNCThreadNotifyExit(void)
 {
 
-    SYS_SEMAPHORE   SemSyncID = SysConnectSemaphore(0, SYS_DEFAULT_MAXCOUNT,
-            SemPSYNCThreads);
-
-    if (SemSyncID == SYS_INVALID_SEMAPHORE)
-        return (ErrGetErrorCode());
-
-    SysReleaseSemaphore(SemSyncID, 1);
-
-    SysCloseSemaphore(SemSyncID);
+    SysReleaseSemaphore(hSyncSem, 1);
 
     return (0);
 
@@ -306,7 +273,12 @@ unsigned int    PSYNCThreadSyncProc(void *pThreadData)
 
     SysLogMessage(LOG_LEV_MESSAGE, "[PSYNC] entry\n");
 
-    if (GwLkLinkLock(pPopLnk) < 0)
+///////////////////////////////////////////////////////////////////////////////
+//  Get configuration handle
+///////////////////////////////////////////////////////////////////////////////
+    SVRCFG_HANDLE   hSvrConfig = SvrGetConfigHandle();
+
+    if (hSvrConfig == INVALID_SVRCFG_HANDLE)
     {
         ErrorPush();
         SysLogMessage(LOG_LEV_MESSAGE, "%s\n", ErrGetErrorString(ErrorFetch()));
@@ -320,16 +292,25 @@ unsigned int    PSYNCThreadSyncProc(void *pThreadData)
     }
 
 ///////////////////////////////////////////////////////////////////////////////
-//  Create handle to shared memory configuration
+//  Get the error account for email that the server is not able to deliver coz
+//  it does not find informations about where it has to deliver
 ///////////////////////////////////////////////////////////////////////////////
-    SHB_HANDLE      hShbPSYNC = ShbConnectBlock(SHB_PSYNCSvr);
+    char            szErrorAccount[MAX_ADDR_NAME] = "";
 
-    if (hShbPSYNC == SHB_INVALID_HANDLE)
+    SvrConfigVar("Pop3SyncErrorAccount", szErrorAccount, sizeof(szErrorAccount) - 1,
+            hSvrConfig, "");
+
+    char const     *pszErrorAccount = (IsEmptyString(szErrorAccount)) ? NULL: szErrorAccount;
+
+///////////////////////////////////////////////////////////////////////////////
+//  Lock the link
+///////////////////////////////////////////////////////////////////////////////
+    if (GwLkLinkLock(pPopLnk) < 0)
     {
         ErrorPush();
-        SysLogMessage(LOG_LEV_ERROR, "%s\n", ErrGetErrorString(ErrorFetch()));
+        SysLogMessage(LOG_LEV_MESSAGE, "%s\n", ErrGetErrorString(ErrorFetch()));
 
-        GwLkLinkUnlock(pPopLnk);
+        SvrReleaseConfigHandle(hSvrConfig);
         GwLkFreePOP3Link(pPopLnk);
 ///////////////////////////////////////////////////////////////////////////////
 //  Notify thread exit semaphore
@@ -366,7 +347,7 @@ unsigned int    PSYNCThreadSyncProc(void *pThreadData)
             UsrGetAddress(pUI, szUserAddress);
 
             if (UPopSyncRemoteLink(szUserAddress, pPopLnk->pszRmtDomain, pPopLnk->pszRmtName,
-                            pPopLnk->pszRmtPassword, pPopLnk->pszAuthType) < 0)
+                            pPopLnk->pszRmtPassword, pPopLnk->pszAuthType, pszErrorAccount) < 0)
                 ErrLogMessage(LOG_LEV_MESSAGE, "[PSYNC] User = \"%s\" - Domain = \"%s\" Failed !\n",
                         pPopLnk->pszName, pPopLnk->pszDomain);
 
@@ -388,7 +369,7 @@ unsigned int    PSYNCThreadSyncProc(void *pThreadData)
 //  Sync ( "pszDomain" == "?" + masq-domain or "pszDomain" == "&" + add-domain )
 ///////////////////////////////////////////////////////////////////////////////
         if (UPopSyncRemoteLink(pPopLnk->pszDomain, pPopLnk->pszRmtDomain, pPopLnk->pszRmtName,
-                        pPopLnk->pszRmtPassword, pPopLnk->pszAuthType) < 0)
+                        pPopLnk->pszRmtPassword, pPopLnk->pszAuthType, pszErrorAccount) < 0)
             ErrLogMessage(LOG_LEV_MESSAGE,
                     "[PSYNC/MASQ] MasqDomain = \"%s\" - RmtDomain = \"%s\" - RmtName = \"%s\" Failed !\n",
                     pPopLnk->pszDomain + 1, pPopLnk->pszRmtDomain, pPopLnk->pszRmtName);
@@ -409,7 +390,7 @@ unsigned int    PSYNCThreadSyncProc(void *pThreadData)
 //  Sync ( "pszDomain" == "@" + domain )
 ///////////////////////////////////////////////////////////////////////////////
         if (UPopSyncRemoteLink(szSyncAddress, pPopLnk->pszRmtDomain, pPopLnk->pszRmtName,
-                        pPopLnk->pszRmtPassword, pPopLnk->pszAuthType) < 0)
+                        pPopLnk->pszRmtPassword, pPopLnk->pszAuthType, pszErrorAccount) < 0)
             ErrLogMessage(LOG_LEV_MESSAGE,
                     "[PSYNC/EXT] Acount = \"%s\" - RmtDomain = \"%s\" - RmtName = \"%s\" Failed !\n",
                     szSyncAddress, pPopLnk->pszRmtDomain, pPopLnk->pszRmtName);
@@ -420,13 +401,9 @@ unsigned int    PSYNCThreadSyncProc(void *pThreadData)
 ///////////////////////////////////////////////////////////////////////////////
     PSYNCThreadCountAdd(-1, hShbPSYNC);
 
-///////////////////////////////////////////////////////////////////////////////
-//  Free handle to shared memory configuration
-///////////////////////////////////////////////////////////////////////////////
-    ShbCloseBlock(hShbPSYNC);
-
 
     GwLkLinkUnlock(pPopLnk);
+    SvrReleaseConfigHandle(hSvrConfig);
     GwLkFreePOP3Link(pPopLnk);
 
 ///////////////////////////////////////////////////////////////////////////////
