@@ -1,6 +1,6 @@
 /*
- *  MailSvr by Davide Libenzi ( Intranet and Internet mail server )
- *  Copyright (C) 1999  Davide Libenzi
+ *  XMail by Davide Libenzi ( Intranet and Internet mail server )
+ *  Copyright (C) 1999,2000,2001  Davide Libenzi
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  Davide Libenzi <davide_libenzi@mycio.com>
+ *  Davide Libenzi <davidel@xmailserver.org>
  *
  */
 
@@ -57,7 +57,6 @@
 #define FILTER_OUT_EXITCODE         99
 #define MODIFY_EXITCODE             100
 #define MAX_PEEK_FILES              32
-#define STD_SMAILTHREAD_SLEEP_TIME  4
 
 
 
@@ -115,19 +114,19 @@ static int      SMAILFilterMacroSubstitutes(char **ppszCmdTokens, char const * p
 static SMAILConfig *SMAILGetConfigCopy(SHB_HANDLE hShbSMAIL)
 {
 
-    SMAILConfig    *pPSYNCCfg = (SMAILConfig *) ShbLock(hShbSMAIL);
+    SMAILConfig    *pLMAILCfg = (SMAILConfig *) ShbLock(hShbSMAIL);
 
-    if (pPSYNCCfg == NULL)
+    if (pLMAILCfg == NULL)
         return (NULL);
 
-    SMAILConfig    *pNewPSYNCCfg = (SMAILConfig *) SysAlloc(sizeof(SMAILConfig));
+    SMAILConfig    *pNewLMAILCfg = (SMAILConfig *) SysAlloc(sizeof(SMAILConfig));
 
-    if (pNewPSYNCCfg != NULL)
-        memcpy(pNewPSYNCCfg, pPSYNCCfg, sizeof(SMAILConfig));
+    if (pNewLMAILCfg != NULL)
+        memcpy(pNewLMAILCfg, pLMAILCfg, sizeof(SMAILConfig));
 
     ShbUnlock(hShbSMAIL);
 
-    return (pNewPSYNCCfg);
+    return (pNewLMAILCfg);
 
 }
 
@@ -185,28 +184,19 @@ static int      SMAILLogEnabled(SHB_HANDLE hShbSMAIL, SMAILConfig * pSMAILCfg)
 unsigned int    SMAILThreadProc(void *pThreadData)
 {
 
-    SHB_HANDLE      hShbSMAIL = ShbConnectBlock(SHB_SMAILSvr);
-
-    if (hShbSMAIL == SHB_INVALID_HANDLE)
-    {
-        ErrorPush();
-        SysLogMessage(LOG_LEV_ERROR, "%s\n", ErrGetErrorString());
-        return (ErrorPop());
-    }
-
     SMAILConfig    *pSMAILCfg = (SMAILConfig *) ShbLock(hShbSMAIL);
 
     if (pSMAILCfg == NULL)
     {
         ErrorPush();
         SysLogMessage(LOG_LEV_ERROR, "%s\n", ErrGetErrorString());
-        ShbCloseBlock(hShbSMAIL);
         return (ErrorPop());
     }
 
 ///////////////////////////////////////////////////////////////////////////////
-//  Get retry timeout and thread id
+//  Get thread id
 ///////////////////////////////////////////////////////////////////////////////
+    int             iSleepTimeout = pSMAILCfg->iSleepTimeout;
     long            lThreadId = pSMAILCfg->lThreadCount;
 
 ///////////////////////////////////////////////////////////////////////////////
@@ -243,7 +233,7 @@ unsigned int    SMAILThreadProc(void *pThreadData)
         int             iProcessResult = SMAILTryProcessSpool(hShbSMAIL);
 
         if (iProcessResult == ERR_NO_SMTP_SPOOL_FILES)
-            SysSleep(STD_SMAILTHREAD_SLEEP_TIME);
+            SysSleep(iSleepTimeout);
 
     }
 
@@ -253,8 +243,6 @@ unsigned int    SMAILThreadProc(void *pThreadData)
     SMAILThreadCountAdd(-1, hShbSMAIL);
 
 
-    ShbCloseBlock(hShbSMAIL);
-
     SysLogMessage(LOG_LEV_MESSAGE, "SMAIL thread [%02ld] stopped\n", lThreadId);
 
     return (0);
@@ -505,11 +493,21 @@ static int      SMAILMailingListExplode(UserInfo * pUI, SPLF_HANDLE hFSpool)
     if (USmtpSplitEmailAddr(ppszRcpt[0], szDestUser, szDestDomain) < 0)
         return (ErrGetErrorCode());
 
+///////////////////////////////////////////////////////////////////////////////
+//  Get Mailing List Sender address. If this account variable does not exist
+//  the sender will be the "real" message sender
+///////////////////////////////////////////////////////////////////////////////
+    char           *pszMLSender = UsrGetUserInfoVar(pUI, "ListSender");
+
 
     USRML_HANDLE    hUsersDB = UsrMLOpenDB(pUI);
 
     if (hUsersDB == INVALID_USRML_HANDLE)
-        return (ErrGetErrorCode());
+    {
+        ErrorPush();
+        SysFreeCheck(pszMLSender);
+        return (ErrorPop());
+    }
 
 ///////////////////////////////////////////////////////////////////////////////
 //  Mailing list scan
@@ -526,17 +524,19 @@ static int      SMAILMailingListExplode(UserInfo * pUI, SPLF_HANDLE hFSpool)
         if (QueGetTempFile(NULL, szSpoolTmpFile, iQueueSplitLevel) < 0)
         {
             ErrorPush();
+            SysFreeCheck(pszMLSender);
             UsrMLFreeUser(pMLUI);
             UsrMLCloseDB(hUsersDB);
             return (ErrorPop());
         }
 
 ///////////////////////////////////////////////////////////////////////////////
-//  Create spool file
+//  Create spool file. If "pszMLSender" is NULL the original sender is kept
 ///////////////////////////////////////////////////////////////////////////////
-        if (USmlCreateSpoolFile(hFSpool, NULL, pMLUI->pszAddress, szSpoolTmpFile) < 0)
+        if (USmlCreateSpoolFile(hFSpool, pszMLSender, pMLUI->pszAddress, szSpoolTmpFile) < 0)
         {
             ErrorPush();
+            SysFreeCheck(pszMLSender);
             UsrMLFreeUser(pMLUI);
             UsrMLCloseDB(hUsersDB);
             return (ErrorPop());
@@ -549,6 +549,7 @@ static int      SMAILMailingListExplode(UserInfo * pUI, SPLF_HANDLE hFSpool)
         {
             ErrorPush();
             SysRemove(szSpoolTmpFile);
+            SysFreeCheck(pszMLSender);
             UsrMLFreeUser(pMLUI);
             UsrMLCloseDB(hUsersDB);
             return (ErrorPop());
@@ -559,6 +560,7 @@ static int      SMAILMailingListExplode(UserInfo * pUI, SPLF_HANDLE hFSpool)
 
     UsrMLCloseDB(hUsersDB);
 
+    SysFreeCheck(pszMLSender);
 
     return (0);
 
@@ -1255,7 +1257,7 @@ static int      SMAILCmd_smtprelay(SHB_HANDLE hShbSMAIL, char const * pszDestDom
         USmtpCleanupError(&SMTPE);
 
         if (USmtpSendMail(ppszRelays[ss], pszSMTPDomain, pszSendMailFrom, pszSendRcptTo,
-                pszMailFile, &SMTPE) == 0)
+                        pszMailFile, &SMTPE) == 0)
         {
 ///////////////////////////////////////////////////////////////////////////////
 //  Log Mailer operation
