@@ -1,6 +1,6 @@
 /*
- *  MailSvr by Davide Libenzi ( Intranet and Internet mail server )
- *  Copyright (C) 1999  Davide Libenzi
+ *  XMail by Davide Libenzi ( Intranet and Internet mail server )
+ *  Copyright (C) 1999,2000,2001  Davide Libenzi
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  Davide Libenzi <davide_libenzi@mycio.com>
+ *  Davide Libenzi <davidel@xmailserver.org>
  *
  */
 
@@ -35,26 +35,15 @@
 
 typedef void   *SHB_HANDLE;
 
-struct SharedBlock
-{
-    unsigned long   ulOwnerID;
-    unsigned int    uSize;
-    SYS_IPCNAME     ShmName;
-    SYS_IPCNAME     SemName;
-    SYS_SEMAPHORE   SemID;
-    SYS_SHMEM       ShmID;
-};
 
 
 
 
 
-int             ShbCreateBlock(SharedBlock & SHB, unsigned int uSize);
-int             ShbDestroyBlock(SharedBlock & SHB);
-SHB_HANDLE      ShbConnectBlock(SharedBlock & SHB);
-void            ShbCloseBlock(SHB_HANDLE hBlock);
+SHB_HANDLE      ShbCreateBlock(unsigned int uSize);
+int             ShbCloseBlock(SHB_HANDLE hBlock);
 void           *ShbLock(SHB_HANDLE hBlock);
-void            ShbUnlock(SHB_HANDLE hBlock);
+int             ShbUnlock(SHB_HANDLE hBlock);
 
 
 
