@@ -1,6 +1,6 @@
 /*
- *  MailSvr by Davide Libenzi ( Intranet and Internet mail server )
- *  Copyright (C) 1999  Davide Libenzi
+ *  XMail by Davide Libenzi ( Intranet and Internet mail server )
+ *  Copyright (C) 1999,2000,2001  Davide Libenzi
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  Davide Libenzi <davide_libenzi@mycio.com>
+ *  Davide Libenzi <davidel@xmailserver.org>
  *
  */
 
@@ -29,11 +29,9 @@
 ///////////////////////////////////////////////////////////////////////////////
 // Setup for the use of Maildir mailbox delivery
 ///////////////////////////////////////////////////////////////////////////////
-#ifdef CONFIG_MAILDIR
-#undef CONFIG_MAILDIR
-#else           // #ifdef CONFIG_MAILDIR
-// #define CONFIG_MAILDIR
-#endif          // #ifdef CONFIG_MAILDIR
+#if defined(__LINUX__) || defined(__SOLARIS__)
+#define CONFIG_MAILDIR
+#endif          // #if defined(__LINUX__) || defined(__SOLARIS__)
 
 
 
