@@ -1,6 +1,6 @@
 /*
- *  MailSvr by Davide Libenzi ( Intranet and Internet mail server )
- *  Copyright (C) 1999  Davide Libenzi
+ *  XMail by Davide Libenzi ( Intranet and Internet mail server )
+ *  Copyright (C) 1999,2000,2001  Davide Libenzi
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  Davide Libenzi <davide_libenzi@mycio.com>
+ *  Davide Libenzi <davidel@xmailserver.org>
  *
  */
 
@@ -44,9 +44,15 @@
 #include "SysIncludeLinux.h"
 
 #else           // #ifdef __LINUX__
+#ifdef __SOLARIS__
+
+#include "SysIncludeSolaris.h"
+
+#else           // #ifdef __SOLARIS__
 
 #error System type not defined
 
+#endif          // #ifdef __SOLARIS__
 #endif          // #ifdef __LINUX__
 #endif          // #ifdef WIN32
 
@@ -54,11 +60,12 @@
 
 #include "SysTypes.h"
 
-
 #include "SysMacros.h"
 
+#include "SysLists.h"
 
 #include "Errors.h"
 
 
+
 #endif
