@@ -1,6 +1,6 @@
 /*
- *  MailSvr by Davide Libenzi ( Intranet and Internet mail server )
- *  Copyright (C) 1999  Davide Libenzi
+ *  XMail by Davide Libenzi ( Intranet and Internet mail server )
+ *  Copyright (C) 1999,2000,2001  Davide Libenzi
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  Davide Libenzi <davide_libenzi@mycio.com>
+ *  Davide Libenzi <davidel@xmailserver.org>
  *
  */
 
@@ -39,6 +39,7 @@
 #include "UsrUtils.h"
 #include "Maildir.h"
 #include "TabIndex.h"
+#include "SMTPUtils.h"
 #include "UsrAuth.h"
 
 
@@ -133,7 +134,7 @@ static int      UsrWriteInfoList(HSLIST & InfoList, FILE * pProfileFile);
 static int      UsrLoadUserInfo(HSLIST & InfoList, unsigned int uUserID, const char *pszFilePath);
 static int      UsrLoadUserDefaultInfo(HSLIST & InfoList);
 static int      UsrAliasLookupNameLK(const char *pszAlsFilePath, const char *pszDomain,
-                        const char *pszAlias, char *pszName = NULL);
+                        const char *pszAlias, char *pszName = NULL, bool bWildMatch = true);
 static int      UsrWriteAlias(FILE * pAlsFile, AliasInfo * pAI);
 static bool     UsrIsWildAlias(char const * pszAlias);
 static int      UsrRemoveUserAlias(char const * pszDomain, char const * pszName);
@@ -714,7 +715,7 @@ static int      UsrLoadUserDefaultInfo(HSLIST & InfoList)
 
 
 static int      UsrAliasLookupNameLK(const char *pszAlsFilePath, const char *pszDomain,
-                        const char *pszAlias, char *pszName)
+                        const char *pszAlias, char *pszName, bool bWildMatch)
 {
 ///////////////////////////////////////////////////////////////////////////////
 //  Lookup record using the specified index ( lookup precise aliases )
@@ -735,6 +736,11 @@ static int      UsrAliasLookupNameLK(const char *pszAlsFilePath, const char *psz
         return (1);
     }
 
+///////////////////////////////////////////////////////////////////////////////
+//  We can stop here if wild alias matching is not required
+///////////////////////////////////////////////////////////////////////////////
+    if (!bWildMatch)
+        return (0);
 
 ///////////////////////////////////////////////////////////////////////////////
 //  Lookup record using the specified index ( lookup wild aliases grouped
@@ -783,7 +789,7 @@ static int      UsrAliasLookupNameLK(const char *pszAlsFilePath, const char *psz
 
 
 int             UsrAliasLookupName(const char *pszDomain, const char *pszAlias,
-                        char *pszName)
+                        char *pszName, bool bWildMatch)
 {
 
     char            szAlsFilePath[SYS_MAX_PATH] = "";
@@ -798,7 +804,8 @@ int             UsrAliasLookupName(const char *pszDomain, const char *pszAlias,
         return (0);
 
 
-    int             iLookupResult = UsrAliasLookupNameLK(szAlsFilePath, pszDomain, pszAlias, pszName);
+    int             iLookupResult = UsrAliasLookupNameLK(szAlsFilePath, pszDomain,
+            pszAlias, pszName, bWildMatch);
 
 
     RLckUnlockSH(hResLock);
@@ -1257,6 +1264,12 @@ static int      UsrRemoveUserAlias(char const * pszDomain, char const * pszName)
         return (ERR_FILE_CREATE);
     }
 
+
+    char            szUserAddress[MAX_ADDR_NAME] = "";
+
+    sprintf(szUserAddress, "%s@%s", pszName, pszDomain);
+
+
     int             iAliasFound = 0;
     char            szAlsLine[USR_ALIAS_LINE_MAX] = "";
 
@@ -1270,8 +1283,9 @@ static int      UsrRemoveUserAlias(char const * pszDomain, char const * pszName)
         int             iFieldsCount = StrStringsCount(ppszStrings);
 
         if ((iFieldsCount >= alsMax) &&
-                (stricmp(pszName, ppszStrings[alsName]) == 0) &&
-                (stricmp(pszDomain, ppszStrings[alsDomain]) == 0))
+                (((stricmp(pszName, ppszStrings[alsName]) == 0) &&
+                    (stricmp(pszDomain, ppszStrings[alsDomain]) == 0)) ||
+                (stricmp(szUserAddress, ppszStrings[alsName]) == 0)))
         {
 
             ++iAliasFound;
@@ -1387,14 +1401,28 @@ UserInfo       *UsrGetUserByName(const char *pszDomain, const char *pszName)
 
 
 UserInfo       *UsrGetUserByNameOrAlias(const char *pszDomain, const char *pszName,
-                        char *pszRealUser)
+                        char *pszRealAddr)
 {
 
-    char           *pszAliasedUser = NULL;
-    char            szAliasedUser[MAX_ADDR_NAME] = "";
+    char const     *pszAliasedUser = NULL,
+                   *pszAliasedDomain = NULL;
+    char            szAliasedAccount[MAX_ADDR_NAME] = "",
+                    szAliasedName[MAX_ADDR_NAME] = "",
+                    szAliasedDomain[MAX_ADDR_NAME] = "";
 
-    if (UsrAliasLookupName(pszDomain, pszName, szAliasedUser))
-        pszAliasedUser = szAliasedUser;
+    if (UsrAliasLookupName(pszDomain, pszName, szAliasedAccount))
+    {
+        if (USmtpSplitEmailAddr(szAliasedAccount, szAliasedName, szAliasedDomain) < 0)
+        {
+            pszAliasedUser = szAliasedAccount;
+            pszAliasedDomain = pszDomain;
+        }
+        else
+        {
+            pszAliasedUser = szAliasedName;
+            pszAliasedDomain = szAliasedDomain;
+        }
+    }
 
 
     char            szUsrFilePath[SYS_MAX_PATH] = "";
@@ -1412,14 +1440,10 @@ UserInfo       *UsrGetUserByNameOrAlias(const char *pszDomain, const char *pszNa
     UserInfo       *pUI = UsrGetUserByNameLK(szUsrFilePath, pszDomain, pszName);
 
     if ((pUI == NULL) && (pszAliasedUser != NULL))
-    {
-        pUI = UsrGetUserByNameLK(szUsrFilePath, pszDomain, pszAliasedUser);
+        pUI = UsrGetUserByNameLK(szUsrFilePath, pszAliasedDomain, pszAliasedUser);
 
-        pszName = pszAliasedUser;
-    }
-
-    if (pszRealUser != NULL)
-        strcpy(pszRealUser, pszName);
+    if ((pUI != NULL) && (pszRealAddr != NULL))
+        UsrGetAddress(pUI, pszRealAddr);
 
 
     RLckUnlockSH(hResLock);
@@ -1959,8 +1983,10 @@ static int      UsrWriteUser(UserInfo * pUI, FILE * pUsrFile)
 
 int             UsrAddUser(UserInfo * pUI)
 {
-
-    if (UsrAliasLookupName(pUI->pszDomain, pUI->pszName))
+///////////////////////////////////////////////////////////////////////////////
+//  Search for overlapping alias ( wildcard alias not checked here )
+///////////////////////////////////////////////////////////////////////////////
+    if (UsrAliasLookupName(pUI->pszDomain, pUI->pszName, NULL, false))
     {
         ErrSetErrorCode(ERR_ALIAS_EXIST);
         return (ERR_ALIAS_EXIST);
